\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{books}[2010/02/14]

\LoadClass[letterpaper,10pt,oneside,notitlepage]{article}%	%%was 12pt
\RequirePackage{array}
\usepackage{longtable}				%%replace begin{tabular}[t]-->begin{longtable}[l]
\setcounter{LTchunksize}{900}			%%to avoid longtable needing multiple passes

\def\mywlog{\immediate\write\number-1}

\hbadness=10999%				%%was 9999

\font\tbf cmcsc8 at 8.90pt%			%%was cmcsc10 at 12pt; then cmcsc10 at 10.67pt
\font\bbf cmbx10%				%%was cmbx12
\font\nbf cmr10%				%%was cmr12

\setlength{\oddsidemargin}{-0.325in}%		%%have used -0.5in -0.125in wrt evensidemargin
\setlength{\evensidemargin}{-0.2in}		%%was 0in

\setlength{\topmargin}{0in}%			%%2001sep12: was -0.75in; to 0.15in
\setlength{\headheight}{0pt}
\setlength{\headsep}{0pt}
\setlength{\topskip}{0pt}
\setlength{\topsep}{0pt}

\setlength{\footskip}{0pt}

\setlength{\textwidth}{\paperwidth}
\addtolength{\textwidth}{0in}%			%%==have used -0.6in -1.2in
\setlength{\textheight}{\paperheight}
\addtolength{\textheight}{-0.5in}

\renewcommand\normalsize{\fontsize{10pt}{12pt}\selectfont}%	%%was {12pt}{14pt}
\renewcommand\sc[1]{{\tbf #1}}

\renewcommand{\section}{%
  \@startsection
    {section}{1}{0pt}%				%%==indent from margin;  have used -18pt
      {-3.5ex \@plus -1ex \@minus -.2ex}%	%%skip before;  have used -2.5ex -3.5ex -4.0ex -5.5ex  ==reduce to avoid 3-page report
      {1.0ex \@plus.2ex}%			%%skip after
      {\normalfont\large\bfseries}%
}

\setcounter{secnumdepth}{0}

\newcolumntype{C}{>{$\rm}c<{$}}
\newcolumntype{L}{>{$}l<{$}}
\newcolumntype{R}{>{$\rm}r<{$}}

\pagestyle{empty}

\newcommand\balances[1]{
  \vskip -4.5mm
  \setlength{\extrarowheight}{8pt}%
  \nbf
  \def\arraystretch{0.6}
  \begin{tabular}[t]{lRRRR}%			%%columntype:r allows smallcaps; columntype:R has MinusSign; how to get both??
    #1
  \end{tabular}
}

\newcommand\transactions[1]{
  \vskip -4.5mm
  \setlength{\extrarowheight}{6pt}%
  \nbf
  \def\arraystretch{0.6}
  \begin{longtable}[l]{lllRRlp{2.11in}}
    #1
  \end{longtable}
}

\newcommand\ledger[1]{
  \vskip -4.5mm
  \setlength{\extrarowheight}{6pt}%
  \nbf
  \def\arraystretch{0.6}
  \begin{longtable}[l]{llRRlp{2.61in}}
    #1
  \end{longtable}
}

\newcommand\categorized[1]{
  \vskip -4.5mm
  \setlength{\extrarowheight}{6pt}%
  \nbf
  \def\arraystretch{0.6}
  \begin{longtable}[l]{lRRl}
    #1
  \end{longtable}
}

\newcommand\revisions[1]{
  \vskip -4.5mm
  \setlength{\extrarowheight}{7pt}
  \nbf
  \def\arraystretch{0.6}
  \noindent
  \begin{longtable}[l]{lllRRlp{2.11in}}
  #1
  \end{longtable}
}

\newcommand\notes[1]{
  \vskip -0.0mm
  \setlength{\extrarowheight}{4pt}
  \nbf
  \def\arraystretch{0.6}
  \noindent
  \begin{tabular}[t]{p{7.0in}}
  #1
  \end{tabular}
}

\newcommand\donations[1]{
  \vskip -4.5mm
  \setlength{\extrarowheight}{7pt}
  \nbf
  \def\arraystretch{0.6}
  \noindent
  \begin{longtable}[l]{llRl}
  #1
  \end{longtable}
}

\newcommand\gst[1]{
  \vskip -4.5mm
  \setlength{\extrarowheight}{6pt}
  \nbf
  \def\arraystretch{0.6}
  \noindent
  \begin{longtable}[l]{lllRRlp{2.11in}}
  #1
  \end{longtable}
}

\newcommand\sig[1]{
  \vskip -4.5mm
  \setlength{\extrarowheight}{6pt}
  \nbf
  \def\arraystretch{0.6}
  \noindent
  \begin{tabular}[t]{l}
  #1
  \end{tabular}
}
%%==needed:  short for tshSection??



%%==REST is from beans.cls for some more examples==

\newcommand\BSCbalances[1]{
  \vskip -0.5mm
  \setlength{\extrarowheight}{7pt}
  \nbf
  \def\arraystretch{0.6}
  \begin{tabular}[t]{lR>{\hspace{10mm}}lR}
  #1
  \end{longtable}
}

\newcommand\income[1]{
  \vskip -2mm
  \setlength{\extrarowheight}{6pt}
  \nbf
  \def\arraystretch{0.6}
%%\begin{tabular}[t]{|ll|R|R|R|R|R|R|}
  \begin{tabular}[t]{|ll|RRRRR|R|}
    \hline
    #1
  \end{longtable}
}
\newcommand\incomefoot[1]{
  \hline
  \multicolumn{2}{c|}{}& #1\\
  \cline{3-8}
}

\newcommand\capital[1]{
  \vskip -2mm
  \setlength{\extrarowheight}{6pt}
  \nbf
  \def\arraystretch{0.6}
  \begin{tabular}[t]{|l|R|R|R|R|R|}
    \hline
    #1
  \end{longtable}
}
\newcommand\capitalfoot[1]{
  \hline
  \multicolumn{1}{c|}{} & #1\\
  \cline{2-6}
}

\newcommand\units[1]{
  \vskip -2mm
  \setlength{\extrarowheight}{6pt}
  \nbf
  \def\arraystretch{0.6}
  \begin{tabular}[t]{|lr|R|R|R|R|R|R|}
    \hline
    #1
  \end{longtable}
}
\newcommand\unitsfoot[1]{
  \hline
  \multicolumn{2}{c|}{} & #1\\
  \cline{3-7}
}
